"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toOptions = exports.fieldsToOptions = exports.articlesToOptions = exports.templateToOptions = exports.clingGetApiToken = exports.clingApiRequest = void 0;
const n8n_workflow_1 = require("n8n-workflow");
async function clingApiRequest(apiToken, method, endpoint, body = {}, qs = {}) {
    const authenticationMethod = this.getNodeParameter('authentication', 0, 'basicAuth');
    let auth = {};
    if (authenticationMethod === 'basicAuth') {
        auth = { authorization: `JWT ${apiToken}` };
    }
    else {
        auth = { apikey: `${apiToken}` };
    }
    const options = {
        headers: {
            ...auth,
        },
        method,
        body,
        qs,
        uri: `https://api.cling.se/${endpoint}`,
        json: true,
        gzip: true,
        rejectUnauthorized: true,
    };
    if (Object.keys(qs).length === 0) {
        delete options.qs;
    }
    if (Object.keys(body).length === 0) {
        delete options.body;
    }
    try {
        let i = 0;
        do {
            setTimeout(() => { }, 1000);
            try {
                const returnObjects = await this.helpers.request(options);
                if (returnObjects !== undefined) {
                    return returnObjects;
                }
                else {
                    i = i + 1;
                }
            }
            catch {
                i = i + 1;
            }
        } while (i < 25);
        return [];
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.clingApiRequest = clingApiRequest;
async function clingGetApiToken() {
    const authenticationMethod = this.getNodeParameter('authentication', 0, 'basicAuth');
    if (authenticationMethod === 'basicAuth') {
        const credentials = await this.getCredentials('clingCredentialsApi');
        const options = {
            headers: {},
            method: "post",
            body: {
                "email": credentials.email,
                "password": credentials.password,
            },
            uri: `https://api.cling.se/auth/companyUser`,
            json: true,
            gzip: true,
            rejectUnauthorized: true,
        };
        try {
            let i = 0;
            do {
                setTimeout(() => { }, 1000);
                try {
                    const returnObjects = await this.helpers.request(options);
                    if (returnObjects !== undefined) {
                        return returnObjects.token;
                    }
                    else {
                        i = i + 1;
                    }
                }
                catch {
                    i = i + 1;
                }
            } while (i < 25);
            return [];
        }
        catch (error) {
            throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
        }
    }
    else {
        const credentials = await this.getCredentials('clingCredentialsApiTokenApi');
        return credentials.apiToken;
    }
}
exports.clingGetApiToken = clingGetApiToken;
const templateToOptions = (items) => items.map(({ name, _id }) => ({ name, value: _id }));
exports.templateToOptions = templateToOptions;
const articlesToOptions = (items) => items.map(({ name }) => ({ name, value: name }));
exports.articlesToOptions = articlesToOptions;
const fieldsToOptions = (items) => items.map(({ name, id }) => ({ name, value: id }));
exports.fieldsToOptions = fieldsToOptions;
const toOptions = (items) => items.map(({ name, id }) => ({ name, value: id }));
exports.toOptions = toOptions;
//# sourceMappingURL=GenericFunctions.js.map